==> dl.php?src=linea21_2_3_0.zip: linea21/resources/add_biblio.php <==
<?php
/**
 * Resources module - add bibligraphy reference
 * 
 * Add a bibligraphy reference page
 * 'Resource' module is used by 'Publication' and 'Workshop' modules
 * 
 * @package linea21\modules\resources
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////


$complete_type=strtoupper($mod_inc);
if($type=='P') {
  $requete= SQL_getPublicationTitle($parent);
  $result=$sql_object->DBSelect($requete);
  $current_title=FormatText($result[0]['publi_title'], '2HTML');
  $publi_owner=$result[0]['publi_posted_by'];

  //////////// Check Droits utilisateur ////////////
  if (!$l21auth->hasRight('publication')) ReloadIndex('admin');
  if ($l21auth->GetSessionElement('id')!=$publi_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////
}
if($type=='W') {
  $requete= SQL_getWorkshopRepTitleAndGroup($parent);
  $result=$sql_object->DBSelect($requete);
  $current_title=FormatText($result[0]['workrep_title'].' ('.$result[0]['workshop_denomination'].')', '2HTML');
  $workshop_id=$result[0]['workrep_workshop_id'];

  //////////// Check Droits utilisateur ////////////
  if (!$l21auth->hasRight('workshop')) ReloadIndex('admin');
  if (!$l21auth->isWorkgroupOrganiser($l21auth->GetSessionElement('id'), $sql_object, $workshop_id) && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////
}
?>

<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu',$mod_inc); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('resources',$mod_inc.'_type')." : ". $current_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->
<?php
$form_author='';
$form_title='';
$form_sub_title='';
$form_editor='';
$form_published_date='';

$resources_object= new resources;

if(isset($_POST['enregistrer'])) {
  $data_table=unserialize(urldecode($_POST['data_table']));
  $result=$resources_object->AddBiblioRes($parent, $data_table, $complete_type, $sql_object);
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
  if($result===true) header("Location: ".safe_redirect($link_confirm));
  else  system_error();
}

if(isset($_POST['valider'])) {
    
  $table = array();
  $table[0]=$_POST['biblio_author'];
  $table[1]=$_POST['biblio_title'];
  $table[2]=$_POST['biblio_sub_title'];
  $table[3]=$_POST['biblio_editor'];
  $table[4]=$_POST['biblio_published_date'];
  $table[5]=0; // range

  $integrity=$resources_object->CheckDataIntegrity($table,'BIBLIO');

  if(is_string($integrity)) {
    $text_format='2FIELD';
  } else {
    $text_format='2HTML';
  }
  $form_author=formatText($_POST['biblio_author'], $text_format);
  $form_title=formatText($_POST['biblio_title'], $text_format);
  $form_sub_title=formatText($_POST['biblio_sub_title'], $text_format);
  $form_editor=formatText($_POST['biblio_editor'], $text_format);
  $form_published_date=formatText($_POST['biblio_published_date'], $text_format);

  $table=urlencode(serialize($table));
}

?>

<?php
if(!isset($integrity) || is_string($integrity)) {
  ?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>
<h2><?php echo formatTitleh2($current_title); ?></h2>
<form id="addbiblio" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<p>
		<label for="biblio_author"><?php echo mb_ucfirst(_t('resources','biblio_author')); ?> : *</label>
		<input name="biblio_author" type="text" class="textfield" id="biblio_author" maxlength="200" value="<?php echo $form_author; ?>" required />
	</p>
	<p>
		<label for="biblio_title"><?php echo mb_ucfirst(_t('resources','biblio_title')); ?> : *</label>
		<input name="biblio_title" type="text" class="textfield" id="biblio_title" maxlength="255" value="<?php echo $form_title; ?>" required />
	</p>
	<p>
		<label for="biblio_sub_title"><?php echo mb_ucfirst(_t('resources','biblio_sub_title')); ?> : </label>
		<input name="biblio_sub_title" type="text" class="textfield" id="biblio_sub_title" maxlength="255" value="<?php echo $form_sub_title; ?>" />
	</p>
	<p>
		<label for="biblio_editor"><?php echo mb_ucfirst(_t('resources','biblio_editor')); ?> : </label>
		<input name="biblio_editor" type="text" class="textfield" id="biblio_editor" maxlength="255" value="<?php echo $form_editor; ?>" />
	</p>
	<p>
		<label for="biblio_published_date"><?php echo mb_ucfirst(_t('resources','biblio_published_date')); ?> : </label>
		<input name="biblio_published_date" type="text" class="textfield" id="biblio_published_date" maxlength="100" 	value="<?php echo $form_published_date; ?>" />
	</p>
	<div>
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
		<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
		<?php echo cancel_button($cancel_link); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php
// Récapitulatif
} else	{

  $display_sub_title=empty_none($form_sub_title);
  $display_editor=empty_none($form_editor);
  $display_published_date=empty_none($form_published_date);


  ?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<h2><?php echo formatTitleh2(_t('recap','title')); ?></h2>
<?php
echo "<dl class=\"summary\">\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_author'))." :</dt>\n";
echo "<dd>".$form_author."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_title'))." :</dt>\n";
echo "<dd>".$form_title."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_sub_title'))." :</dt>\n";
echo "<dd>".$display_sub_title."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_editor'))." :</dt>\n";
echo "<dd>".$display_editor."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_published_date'))." :</dt>\n";
echo "<dd>".$display_published_date."</dd>\n";
echo "</dl>\n";
?>
<form id="addbiblio" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<div>
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
		<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
		<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
		<?php echo cancel_button($cancel_link); ?>
		<input name="retour" type="button" value="<?php echo _t('btn','preview') ?>" class="button" id="retour" onclick="history.go(-1);" />
		<input name="enregistrer" type="submit" value="<?php echo _t('btn','save') ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php } ?>

==> dl.php?src=linea21_2_5_0.zip: linea21/resources/add_biblio.php <==
<?php
/**
 * Resources module - add bibligraphy reference
 * 
 * Add a bibligraphy reference page
 * 'Resource' module is used by 'Publication' and 'Workshop' modules
 * 
 * @package linea21\modules\resources
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 * 
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////


$complete_type=strtoupper($mod_inc);
if($type=='P') {
  $requete= SQL_getPublicationTitle($parent);
  $result=$sql_object->DBSelect($requete);
  $current_title=FormatText($result[0]['publi_title'], '2HTML');
  $publi_owner=$result[0]['publi_posted_by'];

  //////////// Check Droits utilisateur ////////////
  if (!$l21auth->hasRight('publication')) ReloadIndex('admin');
  if ($l21auth->GetSessionElement('id')!=$publi_owner && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////
}
if($type=='W') {
  $requete= SQL_getWorkshopRepTitleAndGroup($parent);
  $result=$sql_object->DBSelect($requete);
  $current_title=FormatText($result[0]['workrep_title'].' ('.$result[0]['workshop_denomination'].')', '2HTML');
  $workshop_id=$result[0]['workrep_workshop_id'];

  //////////// Check Droits utilisateur ////////////
  if (!$l21auth->hasRight('workshop')) ReloadIndex('admin');
  if (!$l21auth->isWorkgroupOrganiser($l21auth->GetSessionElement('id'), $sql_object, $workshop_id) && !$l21auth->isSuperAdmin()) ReloadIndex('admin');
  ///////////
}
?>

<div id="chemin">
<ul>
	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home'); ?></a></li>
	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu',$mod_inc); ?></a></li>
	<li><span><?php echo formatNavTitle(_t('resources',$mod_inc.'_type')." : ". $current_title); ?></span></li>
</ul>
</div>
<!--end barre haute -->
<?php
$form_author='';
$form_title='';
$form_sub_title='';
$form_editor='';
$form_published_date='';

$resources_object= new resources;

if(isset($_POST['enregistrer'])) {
  $data_table=unserialize(urldecode($_POST['data_table']));
  $result=$resources_object->AddBiblioRes($parent, $data_table, $complete_type, $sql_object);
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
  if($result===true) {
      header("Location: ".safe_redirect($link_confirm));
      exit;
  }
  else  system_error();
}

if(isset($_POST['valider'])) {
    
  $table = array();
  $table[0]=$_POST['biblio_author'];
  $table[1]=$_POST['biblio_title'];
  $table[2]=$_POST['biblio_sub_title'];
  $table[3]=$_POST['biblio_editor'];
  $table[4]=$_POST['biblio_published_date'];
  $table[5]=0; // range

  $integrity=$resources_object->CheckDataIntegrity($table,'BIBLIO');

  if(is_string($integrity)) {
    $text_format='2FIELD';
  } else {
    $text_format='2HTML';
  }
  $form_author=formatText($_POST['biblio_author'], $text_format);
  $form_title=formatText($_POST['biblio_title'], $text_format);
  $form_sub_title=formatText($_POST['biblio_sub_title'], $text_format);
  $form_editor=formatText($_POST['biblio_editor'], $text_format);
  $form_published_date=formatText($_POST['biblio_published_date'], $text_format);

  $table=urlencode(serialize($table));
}

?>

<?php
if(!isset($integrity) || is_string($integrity)) {
  ?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content"><?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>
<h2><?php echo formatTitleh2($current_title); ?></h2>
<form id="addbiblio" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<p>
		<label for="biblio_author"><?php echo mb_ucfirst(_t('resources','biblio_author')); ?> : *</label>
		<input name="biblio_author" type="text" class="textfield" id="biblio_author" maxlength="200" value="<?php echo $form_author; ?>" required />
	</p>
	<p>
		<label for="biblio_title"><?php echo mb_ucfirst(_t('resources','biblio_title')); ?> : *</label>
		<input name="biblio_title" type="text" class="textfield" id="biblio_title" maxlength="255" value="<?php echo $form_title; ?>" required />
	</p>
	<p>
		<label for="biblio_sub_title"><?php echo mb_ucfirst(_t('resources','biblio_sub_title')); ?> : </label>
		<input name="biblio_sub_title" type="text" class="textfield" id="biblio_sub_title" maxlength="255" value="<?php echo $form_sub_title; ?>" />
	</p>
	<p>
		<label for="biblio_editor"><?php echo mb_ucfirst(_t('resources','biblio_editor')); ?> : </label>
		<input name="biblio_editor" type="text" class="textfield" id="biblio_editor" maxlength="255" value="<?php echo $form_editor; ?>" />
	</p>
	<p>
		<label for="biblio_published_date"><?php echo mb_ucfirst(_t('resources','biblio_published_date')); ?> : </label>
		<input name="biblio_published_date" type="text" class="textfield" id="biblio_published_date" maxlength="100" 	value="<?php echo $form_published_date; ?>" />
	</p>
	<div>
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
		<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
		<?php echo cancel_button($cancel_link); ?>
		<input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php
// Récapitulatif
} else	{

  $display_sub_title=empty_none($form_sub_title);
  $display_editor=empty_none($form_editor);
  $display_published_date=empty_none($form_published_date);


  ?>
<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<h2><?php echo formatTitleh2(_t('recap','title')); ?></h2>
<?php
echo "<dl class=\"summary\">\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_author'))." :</dt>\n";
echo "<dd>".$form_author."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_title'))." :</dt>\n";
echo "<dd>".$form_title."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_sub_title'))." :</dt>\n";
echo "<dd>".$display_sub_title."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_editor'))." :</dt>\n";
echo "<dd>".$display_editor."</dd>\n";
echo "<dt>".mb_ucfirst(_t('resources','biblio_published_date'))." :</dt>\n";
echo "<dd>".$display_published_date."</dd>\n";
echo "</dl>\n";
?>
<form id="addbiblio" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
	<div>
		<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
		<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
		<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
		<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
		<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
		<?php echo cancel_button($cancel_link); ?>
		<input name="retour" type="button" value="<?php echo _t('btn','preview') ?>" class="button" id="retour" onclick="history.go(-1);" />
		<input name="enregistrer" type="submit" value="<?php echo _t('btn','save') ?>" class="button" id="valider" />
	</div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
<?php } ?>
